@@ -1,20 +1,20 @@
 package Dancer2::Template::Tiny;
 # ABSTRACT: Template::Tiny engine for Dancer2
-$Dancer2::Template::Tiny::VERSION = '1.0.0';
+$Dancer2::Template::Tiny::VERSION = '2.0.1';
 use Moo;
 use Carp qw/croak/;
 use Dancer2::Core::Types;
-use Dancer2::Template::Implementation::ForkedTiny;
+use Template::Tiny;
 use Dancer2::FileUtils 'read_file_content';
 
 with 'Dancer2::Core::Role::Template';
 
 has '+engine' => (
-    isa => InstanceOf ['Dancer2::Template::Implementation::ForkedTiny']
+    isa => InstanceOf ['Template::Tiny']
 );
 
 sub _build_engine {
-    Dancer2::Template::Implementation::ForkedTiny->new( %{ $_[0]->config } );
+    Template::Tiny->new( %{ $_[0]->config } );
 }
 
 sub render {
@@ -28,6 +28,10 @@ sub render {
       ? ${$template}
       : read_file_content($template);
 
+    # Template::Tiny doesn't like empty template files (like .dancer), so
+    # don't try to render them. Return an empty (not undef) value instead.
+    return '' unless $template_data;
+
     my $content;
 
     $self->engine->process( \$template_data, $tokens, \$content, )
@@ -50,33 +54,17 @@ Dancer2::Template::Tiny - Template::Tiny engine for Dancer2
 
 =head1 VERSION
 
-version 1.0.0
+version 2.0.1
 
 =head1 SYNOPSIS
 
 This template engine allows you to use L<Template::Tiny> in L<Dancer2>.
 
 L<Template::Tiny> is an implementation of a subset of L<Template::Toolkit> (the
-major parts) which takes much less memory and is faster. If you're only using
+major parts) but takes much less memory and is faster. If you're only using
 the main functions of Template::Toolkit, you could use Template::Tiny. You can
 also seamlessly move back to Template::Toolkit whenever you want.
 
-However, Dancer2 uses a modified version of L<Template::Tiny>, which is L<Dancer2::Template::Implementation::ForkedTiny>. It adds 2 features :
-
-=over
-
-=item *
-
-opening and closing tag are now configurable
-
-=item *
-
-CodeRefs are evaluated and their results is inserted in the result.
-
-=back
-
-You can read more on L<Dancer2::Template::Implementation::ForkedTiny>.
-
 To use this engine, all you need to configure in your L<Dancer2>'s
 C<config.yaml>:
 
@@ -102,8 +90,7 @@ L<Template::Toolkit> for rendering.
 
 =head1 SEE ALSO
 
-L<Dancer2>, L<Dancer2::Core::Role::Template>, L<Template::Tiny>,
-L<Dancer2::Template::Implementation::ForkedTiny>.
+L<Dancer2>, L<Dancer2::Core::Role::Template>, L<Template::Tiny>.
 
 =head1 AUTHOR
 
@@ -111,7 +98,7 @@ Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023 by Alexis Sukrieh.
+This software is copyright (c) 2025 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
